@@ -95,7 +95,7 @@ async def file_transfer_put(url, bucket, bucket_name, ttl):
                 
                 file_path = os.path.join(cache_path, '{}_{}'.format(bucket, bucket_name))
                 print('downloading file from cloud....')
-                ret, e = hmfs_client.get_from_cloud_async(file_path, url)
+                ret, e = await hmfs_client.get_from_cloud_async(file_path, url)
 
                 if ret:
                     print('cloud downloaded. start uploading...')
