@@ -8,6 +8,8 @@ from hamunafs.utils.singleton_wrapper import Singleton
 
 class XRedis(Singleton):
     def __init__(self, host, password, port, db=0):
+        if not self.need_init():
+            return
         self.host = host
         self.password = password
         self.port = port
@@ -16,6 +18,7 @@ class XRedis(Singleton):
         self.connection_lost = True
         
         self._make_conn()
+        self._inited = True
         
     def _background_heartbeat(self):
         print('开始心跳')
